ggcorrplot<-function(df, var, color="#FFFFFF00", stat="signif"){
  m.df<-df %>% spread(Cyt, Value) %>% select(-pats)
  mcor<-cor(m.df, m.df, use="pairwise.complete.obs") # Por defecto usa el método de Pearson.
  mpval<-Hmisc::rcorr(as.matrix(m.df))$P

  df<-mcor %>% as.data.frame() %>% add_column(Var1=rownames(mcor),.before=1) %>%
    gather(Var2, Value, -Var1)
  df.pval<-mpval %>% as.data.frame() %>% add_column(Var1=rownames(mpval),.before=1) %>%
    gather(Var2, Value, -Var1)

  df.pval$Value<-round(df.pval$Value, 3)

  if (stat=="signif"){
    df.pval$Value<-gtools::stars.pval(df.pval$Value)
  }

  order<- mcor %>% as.data.frame() %>% add_column(Var1=rownames(mcor),.before=1) %>% clustsort

  ggplot(df, aes(Var1, Var2))+
    scale_x_discrete(limits=order$x)+
    scale_y_discrete(limits=order$y)+
    geom_tile(aes(fill=Value), color=color)+
    geom_text(data=df.pval, aes(label=Value))+
    scale_fill_gradientn(colors=col2(200))+
    theme(axis.text.x = element_text(angle = 90, hjust = 1, vjust=0.5),
        panel.background = element_blank(),
        axis.ticks = element_blank())
}
